<?php

namespace common\extensions\CustomersRank\backend\controllers;

class ManageRankController extends \common\classes\modules\SceletonExtensionsBackend {

    public $acl = ['BOX_HEADING_CUSTOMERS', 'BOX_CUSTOMERS_RANK'];
    
    public function actionIndex() 
    {
        $this->navigation[] = array('link' => \Yii::$app->urlManager->createUrl('manage-rank/'), 'title' => 'Customers Rank');
        $table = [
            [
                'title' => CR_NAME,
                'not_important' => 0,
            ],
            [
                'title' => CR_RANK,
                'not_important' => 0,
            ],
            [
                'title' => CR_ACTION,
                'not_important' => 0,
            ],
        ];
        return $this->render('index', [
            'table' => $table,
        ]);
    }
    
    public function actionList() 
    {
        \Yii::$app->response->format = \yii\web\Response::FORMAT_JSON;
        
        $draw = \Yii::$app->request->get('draw', 1);
        $start = \Yii::$app->request->get('start', 0);
        $length = \Yii::$app->request->get('length', 10);
        if ($length == -1) {
            $length = 10000;
        }
        
        
        
        $customersQuery = \common\models\Customers::find()
                ->select(['c.customers_id', 'c.customers_firstname', 'c.customers_lastname', 'r.customer_rank'])
                ->from(\common\models\Customers::tableName() . ' c')
                ->leftJoin(\common\extensions\CustomersRank\models\Ranks::tableName() . ' r', 'c.customers_id=r.customers_id')
                ;
        $search = \Yii::$app->request->get('search');
        if (isset($search['value']) && tep_not_null($search['value'])) {
            $keywords = tep_db_input(filter_var($search['value'], FILTER_SANITIZE_STRING));
            $customersQuery->andWhere("c.customers_firstname like '%" . $keywords . "%' or c.customers_lastname like '%" . $keywords . "%'");
        }
        
        $order = \Yii::$app->request->get('order');
        if (isset($order[0]['column']) && $order[0]['dir']) {
            switch ($order[0]['column']) {
                case 0:
                    $customersQuery->orderBy("c.customers_firstname " . tep_db_input(tep_db_prepare_input($order[0]['dir'])));
                    break;
                case 1:
                    $customersQuery->orderBy("r.customer_rank " . tep_db_input(tep_db_prepare_input($order[0]['dir'])));
                    break;
                default:
                    $customersQuery->orderBy("c.customers_firstname, c.customers_lastname");
                    break;
            }
        } else {
            $customersQuery->orderBy('c.customers_firstname, c.customers_lastname');
        }
        
        $responseList = [];
        $rowsShow = 0;
        $rowsTotal = $customersQuery->count();
        $customersQuery->limit($length)->offset($start);
        
        foreach ($customersQuery->asArray()->all() as $customersRow) {
            $rowsShow++;
            $responseList[] = [
                $customersRow['customers_firstname'] . ' ' . $customersRow['customers_lastname'],
                $customersRow['customer_rank'],
                '<a class="btn" href="javascript:void(0);" onclick="return newCustomerRank(' . $customersRow['customers_id'] . ')">Change rank</a>'
            ];
        }
        
        $response = [
            'draw' => $draw,
            'recordsTotal' => $rowsTotal,
            'recordsFiltered' => $rowsShow,
            'data' => $responseList
        ];
        return $response;
    }
    
    public function actionChange() 
    {
        $id = (int)\Yii::$app->request->get('id');
        $rank = filter_var(htmlentities(\Yii::$app->request->get('rank')), FILTER_SANITIZE_STRING);
        
        $ranksRecord = \common\extensions\CustomersRank\models\Ranks::find()
                ->where(['customers_id' => $id])
                ->one();
       if ($ranksRecord instanceof \common\extensions\CustomersRank\models\Ranks) {
           $ranksRecord->customer_rank = $rank;
           $ranksRecord->save();
       } else {
           $customer = \common\models\Customers::find()
                   ->where(['customers_id' => $id])
                   ->one();
           if ($customer instanceof \common\models\Customers) {
            $ranksRecord = new \common\extensions\CustomersRank\models\Ranks();
            $ranksRecord->customers_id = $id;
            $ranksRecord->customer_rank = $rank;
            $ranksRecord->save();
           }
       }
    }
}
